@@ -1,6 +1,6 @@
 """``runway kbenv`` command group."""
 # docs: file://./../../../../docs/source/commands.rst
-from typing import Any  # pylint: disable=W
+from typing import Any
 
 import click
 
@@ -17,8 +17,7 @@ COMMANDS = [install, run]
 @options.debug
 @options.no_color
 @options.verbose
-def kbenv(**_):
-    # type: (Any) -> None
+def kbenv(**_: Any) -> None:
     """kubectl version management and execution.
 
     Compatible with https://github.com/alexppg/kbenv.
