@@ -1,7 +1,5 @@
 #!/usr/bin/env python
 """Module with k8s cluster resources."""
-from __future__ import print_function
-
 import awacs.iam
 from awacs.aws import StringLike  # pylint: disable=no-name-in-module
 from awacs.aws import Allow, Condition, PolicyDocument, Statement
@@ -39,10 +37,9 @@ class Cluster(Blueprint):
         },
     }
 
-    def create_template(self):
+    def create_template(self) -> None:
         """Create template (main function called by Stacker)."""
         template = self.template
-        variables = self.get_variables()
         template.add_version("2010-09-09")
         template.add_description("Kubernetes Master via EKS - V1.0.0")
 
@@ -60,7 +57,7 @@ class Cluster(Blueprint):
                     {"Key": "Project", "Value": "eks"},
                     {"Key": "Name", "Value": Sub("${EksClusterName}-sg-worker-nodes")},
                 ],
-                VpcId=variables["VPC"].ref,
+                VpcId=self.variables["VPC"].ref,
             )
         )
         template.add_output(
@@ -76,10 +73,7 @@ class Cluster(Blueprint):
             iam.Role(
                 "EksServiceRole",
                 AssumeRolePolicyDocument=make_simple_assume_policy("eks.amazonaws.com"),
-                ManagedPolicyArns=[
-                    IAM_POLICY_ARN_PREFIX + i
-                    for i in ["AmazonEKSClusterPolicy", "AmazonEKSServicePolicy"]
-                ],
+                ManagedPolicyArns=[IAM_POLICY_ARN_PREFIX + "AmazonEKSClusterPolicy"],
                 Policies=[
                     iam.Policy(
                         PolicyName="EksServiceRolePolicy",
@@ -116,12 +110,12 @@ class Cluster(Blueprint):
         ekscluster = template.add_resource(
             eks.Cluster(
                 "EksCluster",
-                Name=variables["EksClusterName"].ref,
-                Version=variables["EksVersion"].ref,
+                Name=self.variables["EksClusterName"].ref,
+                Version=self.variables["EksVersion"].ref,
                 RoleArn=eksservicerole.get_att("Arn"),
                 ResourcesVpcConfig=eks.ResourcesVpcConfig(
                     SecurityGroupIds=[ccpsecuritygroup.ref()],
-                    SubnetIds=variables["EksSubnets"].ref,
+                    SubnetIds=self.variables["EksSubnets"].ref,
                 ),
             )
         )
@@ -148,7 +142,7 @@ class Cluster(Blueprint):
                 "VpcId",
                 Description="EKS Cluster VPC Id",
                 Export=Export(Sub("${AWS::StackName}-VpcId")),
-                Value=variables["VPC"].ref,
+                Value=self.variables["VPC"].ref,
             )
         )
         template.add_output(
@@ -156,7 +150,7 @@ class Cluster(Blueprint):
                 "Subnets",
                 Description="EKS Cluster Subnets",
                 Export=Export(Sub("${AWS::StackName}-Subnets")),
-                Value=Join(",", variables["EksSubnets"].ref),
+                Value=Join(",", self.variables["EksSubnets"].ref),
             )
         )
 
@@ -164,6 +158,6 @@ class Cluster(Blueprint):
 # Helper section to enable easy blueprint -> template generation
 # (just run `python <thisfile>` to output the json)
 if __name__ == "__main__":
-    from runway.cfngin.context import Context
+    from runway.context import CfnginContext
 
-    print(Cluster("test", Context({"namespace": "test"}), None).to_json())
+    print(Cluster("test", CfnginContext(parameters={"namespace": "test"})).to_json())
