@@ -1,11 +1,11 @@
 #!/usr/bin/env python
 """Module with static website bucket and CloudFront distribution."""
-from __future__ import print_function
+from __future__ import annotations
 
 import hashlib
 import logging
 import os
-from typing import Any, Dict, List, Union  # pylint: disable=unused-import
+from typing import TYPE_CHECKING, Any, Dict, List, Union
 
 import awacs.awslambda
 import awacs.iam
@@ -28,19 +28,32 @@ from troposphere import (
     iam,
     s3,
 )
+from typing_extensions import TypedDict
 
-from runway.cfngin.blueprints.base import Blueprint
-from runway.cfngin.context import Context
+from ...cfngin.blueprints.base import Blueprint
+from ...context import CfnginContext
+
+if TYPE_CHECKING:
+    from troposphere import Ref  # pylint: disable=ungrouped-imports
+
+    from ...cfngin.blueprints.type_defs import BlueprintVariableTypeDef
 
 LOGGER = logging.getLogger("runway")
 
 IAM_ARN_PREFIX = "arn:aws:iam::aws:policy/service-role/"
 
 
-class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
+class _IndexRewriteFunctionInfoTypeDef(TypedDict, total=False):
+
+    function: awslambda.Function
+    role: iam.Role
+    version: awslambda.Version
+
+
+class StaticSite(Blueprint):
     """CFNgin blueprint for creating S3 bucket and CloudFront distribution."""
 
-    VARIABLES = {
+    VARIABLES: Dict[str, BlueprintVariableTypeDef] = {
         "AcmCertificateArn": {
             "type": str,
             "default": "",
@@ -98,49 +111,41 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
     }
 
     @property
-    def aliases_specified(self):
-        # type: () -> bool
+    def aliases_specified(self) -> bool:
         """Aliases are specified conditional."""
-        return self.get_variables()["Aliases"] != [""]
+        return self.variables["Aliases"] != [""]
 
     @property
-    def cf_enabled(self):
-        # type: () -> bool
+    def cf_enabled(self) -> bool:
         """CloudFront enabled conditional."""
-        return not self.get_variables().get("DisableCloudFront", False)
+        return not self.variables.get("DisableCloudFront", False)
 
     @property
-    def acm_certificate_specified(self):
-        # type: () -> bool
+    def acm_certificate_specified(self) -> bool:
         """ACM Certification specified conditional."""
-        return self.get_variables()["AcmCertificateArn"] != ""
+        return self.variables["AcmCertificateArn"] != ""
 
     @property
-    def cf_logging_enabled(self):
-        # type: () -> bool
+    def cf_logging_enabled(self) -> bool:
         """CloudFront Logging specified conditional."""
-        return self.get_variables()["LogBucketName"] != ""
+        return self.variables["LogBucketName"] != ""
 
     @property
-    def directory_index_specified(self):
-        # type: () -> bool
+    def directory_index_specified(self) -> bool:
         """Directory Index specified conditional."""
-        return self.get_variables()["RewriteDirectoryIndex"] != ""
+        return self.variables["RewriteDirectoryIndex"] != ""
 
     @property
-    def role_boundary_specified(self):
-        # type: () -> bool
+    def role_boundary_specified(self) -> bool:
         """IAM Role Boundary specified conditional."""
-        return self.get_variables()["RoleBoundaryArn"] != ""
+        return self.variables["RoleBoundaryArn"] != ""
 
     @property
-    def waf_name_specified(self):
-        # type: () -> bool
+    def waf_name_specified(self) -> bool:
         """WAF name specified conditional."""
-        return self.get_variables()["WAFWebACL"] != ""
+        return self.variables["WAFWebACL"] != ""
 
-    def create_template(self):
-        # type: () -> None
+    def create_template(self) -> None:
         """Create template (main function called by CFNgin)."""
         self.template.set_version("2010-09-09")
         self.template.set_description("Static Website - Bucket and Distribution")
@@ -155,45 +160,36 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
 
             if self.directory_index_specified:
                 index_rewrite = self._get_index_rewrite_role_function_and_version()
-                lambda_function_associations = self.get_directory_index_lambda_association(
-                    lambda_function_associations, index_rewrite["version"]
+                lambda_function_associations = (
+                    self.get_directory_index_lambda_association(
+                        lambda_function_associations, index_rewrite["version"]
+                    )
                 )
 
             distribution_options = self.get_cloudfront_distribution_options(
                 bucket, oai, lambda_function_associations
             )
-            distribution = self.add_cloudfront_distribution(  # noqa pylint: disable=unused-variable
-                bucket_policy, distribution_options
-            )
+            self.add_cloudfront_distribution(bucket_policy, distribution_options)
         else:
             self.add_bucket_policy(bucket)
 
-    def get_lambda_associations(self):
-        # type: () -> List[cloudfront.LambdaFunctionAssociation]
-        """Retrieve any lambda associations from the instance variables.
-
-        Return:
-            List of Lambda Function association variables
-
-        """
-        variables = self.get_variables()
-
+    def get_lambda_associations(self) -> List[cloudfront.LambdaFunctionAssociation]:
+        """Retrieve any lambda associations from the instance variables."""
         # If custom associations defined, use them
-        if variables["lambda_function_associations"]:
+        if self.variables["lambda_function_associations"]:
             return [
                 cloudfront.LambdaFunctionAssociation(
                     EventType=x["type"], LambdaFunctionARN=x["arn"]
                 )
-                for x in variables["lambda_function_associations"]
+                for x in self.variables["lambda_function_associations"]
             ]
         return []
 
-    def get_directory_index_lambda_association(  # pylint: disable=no-self-use
-        self,
-        lambda_associations,  # type: List[cloudfront.LambdaFunctionAssociation]
-        directory_index_rewrite_version,  # type: awslambda.Version
-    ):
-        # type: (...) ->  List[cloudfront.LambdaFunctionAssociation]
+    @staticmethod
+    def get_directory_index_lambda_association(
+        lambda_associations: List[cloudfront.LambdaFunctionAssociation],
+        directory_index_rewrite_version: awslambda.Version,
+    ) -> List[cloudfront.LambdaFunctionAssociation]:
         """Retrieve the directory index lambda associations with the added rewriter.
 
         Args:
@@ -211,11 +207,10 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
 
     def get_cloudfront_distribution_options(
         self,
-        bucket,  # type: s3.Bucket
-        oai,  # type: cloudfront.CloudFrontOriginAccessIdentity
-        lambda_function_associations,  # type: List[cloudfront.LambdaFunctionAssociation]
-    ):
-        # type: (...) -> Dict[str, Any]
+        bucket: s3.Bucket,
+        oai: cloudfront.CloudFrontOriginAccessIdentity,
+        lambda_function_associations: List[cloudfront.LambdaFunctionAssociation],
+    ) -> Dict[str, Any]:
         """Retrieve the options for our CloudFront distribution.
 
         Args:
@@ -227,8 +222,6 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
             The CloudFront Distribution Options.
 
         """
-        variables = self.get_variables()
-
         if os.getenv("AWS_REGION") == "us-east-1":
             # use global endpoint for us-east-1
             origin = Join(".", [bucket.ref(), "s3.amazonaws.com"])
@@ -255,7 +248,7 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
                 Compress=False,
                 DefaultTTL="86400",
                 ForwardedValues=cloudfront.ForwardedValues(
-                    Cookies=cloudfront.Cookies(Forward="none"), QueryString=False,
+                    Cookies=cloudfront.Cookies(Forward="none"), QueryString=False
                 ),
                 LambdaFunctionAssociations=lambda_function_associations,
                 TargetOriginId="S3Origin",
@@ -263,63 +256,51 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
             ),
             "DefaultRootObject": "index.html",
             "Logging": self.add_logging_bucket(),
-            "PriceClass": variables["PriceClass"],
+            "PriceClass": self.variables["PriceClass"],
             "CustomErrorResponses": [
                 cloudfront.CustomErrorResponse(
                     ErrorCode=response["ErrorCode"],
                     ResponseCode=response["ResponseCode"],
                     ResponsePagePath=response["ResponsePagePath"],
                 )
-                for response in variables["custom_error_responses"]
+                for response in self.variables["custom_error_responses"]
             ],
             "Enabled": True,
             "WebACLId": self.add_web_acl(),
             "ViewerCertificate": self.add_acm_cert(),
         }
 
-    def add_aliases(self):
-        # type: () -> Union[List[str], NoValue]
+    def add_aliases(self) -> Union[List[str], Ref]:
         """Add aliases."""
         if self.aliases_specified:
-            return self.get_variables()["Aliases"]
+            return self.variables["Aliases"]
         return NoValue
 
-    def add_web_acl(self):
-        # type: () -> Union[str, NoValue]
+    def add_web_acl(self) -> Union[str, Ref]:
         """Add Web ACL."""
         if self.waf_name_specified:
-            return self.get_variables()["WAFWebACL"]
+            return self.variables["WAFWebACL"]
         return NoValue
 
-    def add_logging_bucket(self):
-        # type: () -> Union[cloudfront.Logging, NoValue]
+    def add_logging_bucket(self) -> Union[cloudfront.Logging, Ref]:
         """Add Logging Bucket."""
         if self.cf_logging_enabled:
             return cloudfront.Logging(
-                Bucket=Join(
-                    ".", [self.get_variables()["LogBucketName"], "s3.amazonaws.com"]
-                )
+                Bucket=Join(".", [self.variables["LogBucketName"], "s3.amazonaws.com"])
             )
         return NoValue
 
-    def add_acm_cert(self):
-        # type: () -> Union[cloudfront.ViewerCertificate, NoValue]
+    def add_acm_cert(self) -> Union[cloudfront.ViewerCertificate, Ref]:
         """Add ACM cert."""
         if self.acm_certificate_specified:
             return cloudfront.ViewerCertificate(
-                AcmCertificateArn=self.get_variables()["AcmCertificateArn"],
+                AcmCertificateArn=self.variables["AcmCertificateArn"],
                 SslSupportMethod="sni-only",
             )
         return NoValue
 
-    def add_origin_access_identity(self):
-        # type: () -> cloudfront.CloudFrontOriginAccessIdentity
-        """Add the origin access identity resource to the template.
-
-        Returns:
-            The OAI resource
-
-        """
+    def add_origin_access_identity(self) -> cloudfront.CloudFrontOriginAccessIdentity:
+        """Add the origin access identity resource to the template."""
         return self.template.add_resource(
             cloudfront.CloudFrontOriginAccessIdentity(
                 "OAI",
@@ -329,8 +310,7 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
             )
         )
 
-    def add_bucket_policy(self, bucket):
-        # type: (s3.Bucket) -> s3.BucketPolicy
+    def add_bucket_policy(self, bucket: s3.Bucket) -> s3.BucketPolicy:
         """Add a policy to the bucket if CloudFront is disabled. Ensure PublicRead.
 
         Args:
@@ -358,8 +338,7 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
             )
         )
 
-    def add_bucket(self):
-        # type: () -> s3.Bucket
+    def add_bucket(self) -> s3.Bucket:
         """Add the bucket resource along with an output of it's name / website url.
 
         Returns:
@@ -401,8 +380,9 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
 
         return bucket
 
-    def add_cloudfront_bucket_policy(self, bucket, oai):
-        # type (s3.Bucket, cloudfront.CloudFrontOriginAccessIdentity) -> s3.BucketPolicy
+    def add_cloudfront_bucket_policy(
+        self, bucket: s3.Bucket, oai: cloudfront.CloudFrontOriginAccessIdentity
+    ) -> s3.BucketPolicy:
         """Given a bucket and oai resource add cloudfront access to the bucket.
 
         Keyword Args:
@@ -427,11 +407,8 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
         )
 
     def add_lambda_execution_role(
-        self,
-        name="LambdaExecutionRole",  # type: str
-        function_name="",  # type: str
-    ):  # noqa: E124
-        # type: (...) -> iam.Role
+        self, name: str = "LambdaExecutionRole", function_name: str = ""
+    ) -> iam.Role:
         """Create the Lambda@Edge execution role.
 
         Args:
@@ -440,8 +417,6 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
                 attached to.
 
         """
-        variables = self.get_variables()
-
         lambda_resource = Join(
             "",
             [
@@ -475,7 +450,7 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
                     "lambda.amazonaws.com", "edgelambda.amazonaws.com"
                 ),
                 PermissionsBoundary=(
-                    variables["RoleBoundaryArn"]
+                    self.variables["RoleBoundaryArn"]
                     if self.role_boundary_specified
                     else NoValue
                 ),
@@ -501,8 +476,9 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
             )
         )
 
-    def add_cloudfront_directory_index_rewrite(self, role):
-        # type: (iam.Role) -> awslambda.Function
+    def add_cloudfront_directory_index_rewrite(
+        self, role: iam.Role
+    ) -> awslambda.Function:
         """Add an index CloudFront directory index rewrite lambda function to the template.
 
         Keyword Args:
@@ -512,7 +488,6 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
             The CloudFront directory index rewrite lambda function resource.
 
         """
-        variables = self.get_variables()
         code_str = ""
         path = os.path.join(
             os.path.dirname(__file__),
@@ -520,7 +495,7 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
         )
         with open(path) as file_:
             code_str = file_.read().replace(
-                "{{RewriteDirectoryIndex}}", variables["RewriteDirectoryIndex"]
+                "{{RewriteDirectoryIndex}}", self.variables["RewriteDirectoryIndex"]
             )
 
         function = self.template.add_resource(
@@ -545,15 +520,16 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
 
         return function
 
-    def add_cloudfront_directory_index_rewrite_version(self, directory_index_rewrite):
-        # type: (awslambda.Function) -> awslambda.Version
+    def add_cloudfront_directory_index_rewrite_version(
+        self, directory_index_rewrite: awslambda.Function
+    ) -> awslambda.Version:
         """Add a specific version to the directory index rewrite lambda.
 
         Args:
-            directory_index_rewrite (dict): The directory index rewrite lambda resource.
+            directory_index_rewrite: The directory index rewrite lambda resource.
 
         Return:
-            dict: The CloudFront directory index rewrite version.
+            The CloudFront directory index rewrite version.
 
         """
         code_hash = hashlib.md5(
@@ -570,17 +546,18 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
         )
 
     def add_cloudfront_distribution(
-        self, bucket_policy, cloudfront_distribution_options
-    ):
-        # type: (s3.BucketPolicy, Dict[str, Any]) -> cloudfront.Distribution
+        self,
+        bucket_policy: s3.BucketPolicy,
+        cloudfront_distribution_options: Dict[str, Any],
+    ) -> cloudfront.Distribution:
         """Add the CloudFront distribution to the template / output the id and domain name.
 
         Args:
-            bucket_policy (dict): Bucket policy to allow CloudFront access.
-            cloudfront_distribution_options (dict): The distribution options.
+            bucket_policy: Bucket policy to allow CloudFront access.
+            cloudfront_distribution_options: The distribution options.
 
         Return:
-            dict: The CloudFront Distribution resource
+            The CloudFront Distribution resource
 
         """
         distribution = self.template.add_resource(
@@ -608,9 +585,10 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
         )
         return distribution
 
-    def _get_cloudfront_bucket_policy_statements(  # pylint: disable=no-self-use
-        self, bucket, oai
-    ):
+    @staticmethod
+    def _get_cloudfront_bucket_policy_statements(
+        bucket: s3.Bucket, oai: cloudfront.CloudFrontOriginAccessIdentity
+    ) -> List[Statement]:
         return [
             Statement(
                 Action=[awacs.s3.GetObject],
@@ -621,11 +599,15 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
             )
         ]
 
-    def _get_index_rewrite_role_function_and_version(self):
-        res = {}
-        res["role"] = self.add_lambda_execution_role(
-            "CFDirectoryIndexRewriteRole", "CFDirectoryIndexRewrite"
-        )
+    def _get_index_rewrite_role_function_and_version(
+        self,
+    ) -> _IndexRewriteFunctionInfoTypeDef:
+        res: _IndexRewriteFunctionInfoTypeDef = {
+            "role": self.add_lambda_execution_role(
+                "CFDirectoryIndexRewriteRole", "CFDirectoryIndexRewrite"
+            )
+        }
+
         res["function"] = self.add_cloudfront_directory_index_rewrite(res["role"])
         res["version"] = self.add_cloudfront_directory_index_rewrite_version(
             res["function"]
@@ -636,4 +618,4 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
 # Helper section to enable easy blueprint -> template generation
 # (just run `python <thisfile>` to output the json)
 if __name__ == "__main__":
-    print(StaticSite("test", Context({"namespace": "test"}), None).to_json())
+    print(StaticSite("test", CfnginContext(parameters={"namespace": "test"})).to_json())
