@@ -1,41 +1,41 @@
 """AWS IAM hook."""
-# pylint: disable=unused-argument
+from __future__ import annotations
+
 import copy
 import logging
+from typing import TYPE_CHECKING, Any, Dict, Union
 
 from awacs import ecs
 from awacs.aws import Allow, Policy, Statement
 from awacs.helpers.trust import get_ecs_assumerole_policy
 from botocore.exceptions import ClientError
-from six.moves import input
 
-from ..session_cache import get_session
 from . import utils
 
+if TYPE_CHECKING:
+    from mypy_boto3_iam.type_defs import (
+        GetServerCertificateResponseTypeDef,
+        UploadServerCertificateResponseTypeDef,
+    )
+
+    from ...context import CfnginContext
+
 LOGGER = logging.getLogger(__name__)
 
 
-def create_ecs_service_role(provider, context, **kwargs):
-    """Create ecsServieRole, which has to be named exactly that currently.
+def create_ecs_service_role(
+    context: CfnginContext, *, role_name: str = "ecsServiceRole", **_: Any
+) -> bool:
+    """Create ecsServiceRole IAM role.
 
-    http://docs.aws.amazon.com/AmazonECS/latest/developerguide/IAM_policies.html#service_IAM_role
+    https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using-service-linked-roles.html
 
     Args:
-        provider (:class:`runway.cfngin.providers.base.BaseProvider`): Provider
-            instance. (passed in by CFNgin)
-        context (:class:`runway.cfngin.context.Context`): Context instance.
-            (passed in by CFNgin)
-
-    Keyword Args:
-        role_name (str): Name of the role to create.
-            (*default: ecsServiceRole*)
-
-    Returns:
-        bool: Whether or not the hook succeeded.
+        context: Context instance. (passed in by CFNgin)
+        role_name: Name of the role to create.
 
     """
-    role_name = kwargs.get("role_name", "ecsServiceRole")
-    client = get_session(provider.region).client("iam")
+    client = context.get_session().client("iam")
 
     try:
         client.create_role(
@@ -43,11 +43,8 @@ def create_ecs_service_role(provider, context, **kwargs):
             AssumeRolePolicyDocument=get_ecs_assumerole_policy().to_json(),
         )
     except ClientError as err:
-        if "already exists" in str(err):
-            pass
-        else:
+        if "already exists" not in str(err):
             raise
-
     policy = Policy(
         Version="2012-10-17",
         Statement=[
@@ -72,26 +69,28 @@ def create_ecs_service_role(provider, context, **kwargs):
     return True
 
 
-def _get_cert_arn_from_response(response):
+def _get_cert_arn_from_response(
+    response: Union[
+        GetServerCertificateResponseTypeDef, UploadServerCertificateResponseTypeDef
+    ]
+) -> str:
     result = copy.deepcopy(response)
     # GET response returns this extra key
     if "ServerCertificate" in response:
-        result = response["ServerCertificate"]
-    return result["ServerCertificateMetadata"]["Arn"]
+        return response["ServerCertificate"]["ServerCertificateMetadata"]["Arn"]
+    return result["ServerCertificateMetadata"]["Arn"]  # type: ignore
 
 
-def _get_cert_contents(kwargs):
+def _get_cert_contents(kwargs: Dict[str, Any]) -> Dict[str, Any]:
     """Build parameters with server cert file contents.
 
     Args:
-        kwargs (Dict[str, Any]): The keyword args passed to
-            ensure_server_cert_exists, optionally containing the paths to the
-            cert, key and chain files.
+        kwargs: The keyword args passed to ensure_server_cert_exists, optionally
+            containing the paths to the cert, key and chain files.
 
     Returns:
-        Dict[str, Any]: A dictionary containing the appropriate parameters
-            to supply to upload_server_certificate. An empty dictionary if
-            there is a problem.
+        A dictionary containing the appropriate parameters to supply to
+        upload_server_certificate. An empty dictionary if there is a problem.
 
     """
     paths = {
@@ -135,27 +134,21 @@ def _get_cert_contents(kwargs):
     return parameters
 
 
-def ensure_server_cert_exists(provider, context, **kwargs):
+def ensure_server_cert_exists(
+    context: CfnginContext, *, cert_name: str, prompt: bool = True, **kwargs: Any
+) -> Dict[str, str]:
     """Ensure server cert exists.
 
     Args:
-        provider (:class:`runway.cfngin.providers.base.BaseProvider`): Provider
-            instance. (passed in by CFNgin)
-        context (:class:`runway.cfngin.context.Context`): Context instance.
-            (passed in by CFNgin)
-
-    Keyword Args:
-        cert_name (str): Name of the certificate that should exist.
-        prompt (bool): Whether to prompt to upload a certificate if one does
-            not exist. (*default:* ``True``)
+        context: CFNgin context object.
+        cert_name: Name of the certificate that should exist.
+        prompt: Whether to prompt to upload a certificate if one does not exist.
 
     Returns:
-        Dict[str, str]: Dict containing ``status``, ``cert_name``, and
-            ``cert_arn``.
+        Dict containing ``status``, ``cert_name``, and ``cert_arn``.
 
     """
-    client = get_session(provider.region).client("iam")
-    cert_name = kwargs["cert_name"]
+    client = context.get_session().client("iam")
     status = "unknown"
     try:
         response = client.get_server_certificate(ServerCertificateName=cert_name)
@@ -163,22 +156,20 @@ def ensure_server_cert_exists(provider, context, **kwargs):
         status = "exists"
         LOGGER.info("certificate exists: %s (%s)", cert_name, cert_arn)
     except ClientError:
-        if kwargs.get("prompt", True):
+        if prompt:
             upload = input(
                 "Certificate '%s' wasn't found. Upload it now? (yes/no) " % (cert_name,)
             )
             if upload != "yes":
-                return False
+                return {}
 
         parameters = _get_cert_contents(kwargs)
         if not parameters:
-            return False
+            return {}
         response = client.upload_server_certificate(**parameters)
         cert_arn = _get_cert_arn_from_response(response)
         status = "uploaded"
-        LOGGER.info(
-            "uploaded certificate: %s (%s)", cert_name, cert_arn,
-        )
+        LOGGER.info("uploaded certificate: %s (%s)", cert_name, cert_arn)
 
     return {
         "status": status,
