@@ -1,6 +1,13 @@
 """Lookup to provide a default value."""
-# pylint: disable=arguments-differ,unused-argument
-from runway.lookups.handlers.base import LookupHandler
+# pyright: reportIncompatibleMethodOverride=none
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any, Optional
+
+from ....lookups.handlers.base import LookupHandler
+
+if TYPE_CHECKING:
+    from ....context import CfnginContext
 
 TYPE_NAME = "default"
 
@@ -9,20 +16,16 @@ class DefaultLookup(LookupHandler):
     """Lookup to provide a default value."""
 
     @classmethod
-    def handle(cls, value, context=None, provider=None, **kwargs):
+    def handle(  # pylint: disable=arguments-differ
+        cls, value: str, context: Optional[CfnginContext] = None, **_: Any
+    ) -> Any:
         """Use a value from the environment or fall back to a default value.
 
         Allows defaults to be set at the config file level.
 
         Args:
-            value (str): Parameter(s) given to this lookup.
-                ``<env_var>::<default value>``
-            context (:class:`runway.cfngin.context.Context`): Context instance.
-            provider (:class:`runway.cfngin.providers.base.BaseProvider`):
-                Provider instance.
-
-        Returns:
-            str: Looked up value
+            value: Parameter(s) given to this lookup. ``<env_var>::<default value>``
+            context: Context instance.
 
         Example:
             ::
@@ -40,8 +43,8 @@ class DefaultLookup(LookupHandler):
             raise ValueError(
                 "Invalid value for default: %s. Must be in "
                 "<env_var>::<default value> format." % value
-            )
+            ) from None
 
-        if env_var_name in context.environment:
-            return context.environment[env_var_name]
+        if context and env_var_name in context.parameters:
+            return context.parameters[env_var_name]
         return default_val
