@@ -1,35 +1,42 @@
 """File lookup."""
-# pylint: disable=arguments-differ,unused-argument
+# pylint: disable=arguments-differ
+# pyright: reportIncompatibleMethodOverride=none
+from __future__ import annotations
+
 import base64
+import collections.abc
 import json
 import re
+from typing import Any, Callable, Dict, List, Mapping, Sequence, Union, overload
 
 import yaml
-from six import string_types
-from six.moves.collections_abc import Mapping, Sequence  # pylint: disable=E
 from troposphere import Base64, GenericHelperFn
+from typing_extensions import Literal
 
-from runway.lookups.handlers.base import LookupHandler
-
-from ...util import read_value_from_path
+from ....lookups.handlers.base import LookupHandler
+from ...utils import read_value_from_path
 
 TYPE_NAME = "file"
 
 _PARAMETER_PATTERN = re.compile(r"{{([::|\w]+)}}")
 
+ParameterizedObjectTypeDef = Union[bytes, str, Mapping[str, Any], Sequence[Any], Any]
+ParameterizedObjectReturnTypeDef = Union[
+    Dict[str, "ParameterizedObjectReturnTypeDef"],
+    GenericHelperFn,
+    List["ParameterizedObjectReturnTypeDef"],
+]
+
 
 class FileLookup(LookupHandler):
     """File lookup."""
 
     @classmethod
-    def handle(cls, value, context=None, provider=None, **kwargs):
+    def handle(cls, value: str, **_: Any) -> Any:
         r"""Translate a filename into the file contents.
 
         Args:
-            value (str): Parameter(s) given to this lookup.
-            context (:class:`runway.cfngin.context.Context`): Context instance.
-            provider (:class:`runway.cfngin.providers.base.BaseProvider`):
-                Provider instance.
+            value: Parameter(s) given to this lookup.
 
         Fields should use the following format::
 
@@ -104,7 +111,7 @@ class FileLookup(LookupHandler):
                 }
 
             Then assign UserData in a LaunchConfiguration or Instance to
-            ``self.get_variables()["UserData"]``. Note that we use AWSHelperFn
+            ``self.variables["UserData"]``. Note that we use AWSHelperFn
             as the type because the parameterized-b64 codec returns either a
             Base64 or a GenericHelperFn troposphere object.
 
@@ -150,51 +157,57 @@ class FileLookup(LookupHandler):
         except ValueError:
             raise TypeError(
                 'File value must be of the format "<codec>:<path>" (got %s)' % (value)
-            )
-
-        value = read_value_from_path(path)
-
-        return CODECS[codec](value)
+            ) from None
+        return CODECS[codec](read_value_from_path(path))
 
 
-def _parameterize_string(raw):
+def _parameterize_string(raw: str) -> GenericHelperFn:
     """Substitute placeholders in a string using CloudFormation references.
 
     Args:
-        raw (str): String to be processed. Byte strings are not
-            supported; decode them before passing them to this function.
+        raw: String to be processed. Byte strings are not supported; decode them
+        before passing them to this function.
 
     Returns:
-        str | :class:`troposphere.GenericHelperFn`: An expression with
-            placeholders from the input replaced, suitable to be passed to
-            Troposphere to be included in CloudFormation template. This will
-            be the input string without modification if no substitutions are
-            found, and a composition of CloudFormation calls otherwise.
+        An expression with placeholders from the input replaced, suitable to be
+        passed to Troposphere to be included in CloudFormation template.
+        This will be the input string without modification if no substitutions
+        are found, and a composition of CloudFormation calls otherwise.
 
     """
-    parts = []
+    parts: List[Any] = []
     s_index = 0
 
     for match in _PARAMETER_PATTERN.finditer(raw):
         parts.append(raw[s_index : match.start()])
-        parts.append({u"Ref": match.group(1)})
+        parts.append({"Ref": match.group(1)})
         s_index = match.end()
 
     if not parts:
         return GenericHelperFn(raw)
 
     parts.append(raw[s_index:])
-    return GenericHelperFn({u"Fn::Join": [u"", parts]})
+    return GenericHelperFn({"Fn::Join": ["", parts]})
 
 
-def parameterized_codec(raw, b64):
+@overload
+def parameterized_codec(
+    raw: Union[bytes, str], b64: Literal[False] = ...
+) -> GenericHelperFn:
+    ...
+
+
+@overload
+def parameterized_codec(raw: Union[bytes, str], b64: Literal[True] = ...) -> Base64:
+    ...
+
+
+def parameterized_codec(raw: Union[bytes, str], b64: bool = False) -> Any:
     """Parameterize a string, possibly encoding it as Base64 afterwards.
 
     Args:
-        raw (Union[bytes, str]): String to be processed. Byte strings will be
-            interpreted as UTF-8.
-        b64 (bool): Whether to wrap the output in a Base64 CloudFormation
-            call.
+        raw: String to be processed. Byte strings will be interpreted as UTF-8.
+        b64: Whether to wrap the output in a Base64 CloudFormation call.
 
     Returns:
         :class:`troposphere.AWSHelperFn`: Output to be included in a
@@ -212,7 +225,24 @@ def parameterized_codec(raw, b64):
     return Base64(result.data) if b64 else result
 
 
-def _parameterize_obj(obj):
+@overload
+def _parameterize_obj(obj: Union[bytes, str]) -> GenericHelperFn:
+    ...
+
+
+@overload
+def _parameterize_obj(obj: Mapping[str, Any]) -> ParameterizedObjectReturnTypeDef:
+    ...
+
+
+@overload
+def _parameterize_obj(obj: List[Any]) -> ParameterizedObjectReturnTypeDef:
+    ...
+
+
+def _parameterize_obj(
+    obj: ParameterizedObjectTypeDef,
+) -> ParameterizedObjectReturnTypeDef:
     """Recursively parameterize all strings contained in an object.
 
     Parametrizes all values of a Mapping, all items of a Sequence, an
@@ -221,7 +251,7 @@ def _parameterize_obj(obj):
     Byte strings will be interpreted as UTF-8.
 
     Args:
-        obj (Any): Data to parameterize.
+        obj: Data to parameterize.
 
     Return:
         A parameterized object to be included in a CloudFormation template.
@@ -229,38 +259,38 @@ def _parameterize_obj(obj):
         and strings possibly replaced by compositions of function calls.
 
     """
-    if isinstance(obj, Mapping):
-        return dict((key, _parameterize_obj(value)) for key, value in obj.items())
     if isinstance(obj, bytes):
         return _parameterize_string(obj.decode("utf8"))
-    if isinstance(obj, string_types):
+    if isinstance(obj, str):
         return _parameterize_string(obj)
-    if isinstance(obj, Sequence):
-        return list(_parameterize_obj(item) for item in obj)
+    if isinstance(obj, collections.abc.Mapping):
+        return {key: _parameterize_obj(value) for key, value in obj.items()}
+    if isinstance(obj, collections.abc.Sequence):
+        return [_parameterize_obj(item) for item in obj]
     return obj
 
 
 class SafeUnicodeLoader(yaml.SafeLoader):
     """Safe unicode loader."""
 
-    def construct_yaml_str(self, node):
+    def construct_yaml_str(self, node: Any) -> Any:
         """Construct yaml str."""
         return self.construct_scalar(node)
 
 
-def yaml_codec(raw, parameterized=False):
+def yaml_codec(raw: str, parameterized: bool = False) -> Any:
     """YAML codec."""
     data = yaml.load(raw, Loader=SafeUnicodeLoader)
     return _parameterize_obj(data) if parameterized else data
 
 
-def json_codec(raw, parameterized=False):
+def json_codec(raw: str, parameterized: bool = False) -> Any:
     """JSON codec."""
     data = json.loads(raw)
     return _parameterize_obj(data) if parameterized else data
 
 
-CODECS = {
+CODECS: Dict[str, Callable[..., Any]] = {
     "plain": lambda x: x,
     "base64": lambda x: base64.b64encode(x.encode("utf8")).decode("utf-8"),
     "parameterized": lambda x: parameterized_codec(x, False),
