@@ -1,132 +1,33 @@
-""".. Base class for lookup handlers.
+"""Base class for lookup handlers."""
+from __future__ import annotations
 
-.. _lookup arguments:
-
-****************
-Lookup Arguments
-****************
-
-Arguments can be passed to Lookups to effect how they function.
-
-To provide arguments to a Lookup, use a double-colon (``::``) after the
-query. Each argument is then defined as a **key** and **value** seperated with
-equals (``=``) and the arguments theselves are seperated with a comma (``,``).
-The arguments can have an optional space after the comma and before the next
-key to make them easier to read but this is not required. The value of all
-arguments are read as strings.
-
-.. rubric:: Example
-.. code-block:: yaml
-
-    ${var my_query::default=true, transform=bool}
-    ${env MY_QUERY::default=1,transform=bool}
-
-Each Lookup may have their own, specific arguments that it uses to modify its
-functionality or the value it returns. There is also a common set of arguments
-that all Lookups accept.
-
-.. _Common Lookup Arguments:
-
-Common Lookup Arguments
-=======================
-
-**default (Any)**
-    If the Lookup is unable to find a value for the provided query, this
-    value will be returned instead of raising an exception.
-
-**get (Optional[str])**
-    Can be used on a dictionary type object to retrieve a specific piece of
-    data. This is executed after the optional ``load`` step.
-
-**indent (Optional[int])**
-    Number of spaces to use per indent level when transforming a dictionary
-    type object to a string.
-
-**load (Optional[str])**
-    Load the data to be processed by a Lookup using a specific parser. This is
-    the first action taking on the data after it has been retrieved from its
-    source. The data must be in a format that is supported by the parser
-    in order for it to be used.
-
-    **json**
-        Loads a JSON seralizable string into a dictionary like object.
-    **troposphere**
-        Loads the ``properties`` of a subclass of ``troposphere.BaseAWSObject``
-        into a dictionary.
-    **yaml**
-        Loads a YAML seralizable string into a dictionary like object.
-
-**region (Optional[str])**
-    AWS region used when creating a ``boto3.Session`` to retrieve data.
-    If not provided, the region currently being processed will be used.
-    This can be specified to always get data from one region regardless of
-    region is being deployed to.
-
-**transform (Optional[str])**
-    Transform the data that will be returned by a Lookup into a different
-    data type. This is the last action taking on the data before it is
-    returned. Supports the following:
-
-    **str**
-        Converts any value to a string. The original data type determines the
-        end result.
-
-        ``list``, ``set``, and ``tuple`` will become a comma delimited list
-
-        ``dict`` and anything else will become an escaped JSON string.
-    **bool**
-        Converts a string or boolean value into a boolean.
-
-.. rubric:: Example
-.. code-block:: yaml
-
-  deployments:
-    - parameters:
-        some_variable: ${var some_value::default=my_value}
-        comma_list: ${var my_list::default=undefined, transform=str}
-
-"""
 import json
 import logging
-from distutils.util import strtobool  # pylint: disable=E
-from typing import (  # noqa: F401 pylint: disable=W
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    Optional,
-    Tuple,
-    Union,
-)
+from distutils.util import strtobool
+from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence, Set, Tuple, Union, cast
 
 import yaml
-from six import string_types
 from troposphere import BaseAWSObject
 
-from runway.cfngin.util import read_value_from_path
-from runway.util import MutableMap
+from ...cfngin.utils import read_value_from_path
+from ...utils import MutableMap
 
-# python2 supported pylint sees this is cyclic even though its only for type checking
-# pylint: disable=cyclic-import
 if TYPE_CHECKING:
-    from ...context import Context  # noqa: F401 pylint: disable=unused-import
+    from ...cfngin.providers.aws.default import Provider
+    from ...context import CfnginContext, RunwayContext
+    from ...variables import VariableValue
 
 LOGGER = logging.getLogger(__name__)
 
 
-class LookupHandler(object):
+class LookupHandler:
     """Base class for lookup handlers."""
 
     @classmethod
-    def dependencies(cls, _lookup_data):
+    def dependencies(cls, __lookup_query: VariableValue) -> Set[str]:
         """Calculate any dependencies required to perform this lookup.
 
-        Note that lookup_data may not be (completely) resolved at this time.
-
-        Args:
-            lookup_data (VariableValue): Parameter(s) given to this lookup.
-
-        Returns:
-            Set
+        Note that lookup_query may not be (completely) resolved at this time.
 
         """
         return set()
@@ -134,23 +35,21 @@ class LookupHandler(object):
     @classmethod
     def format_results(
         cls,
-        value,  # type: Any
-        get=None,  # type: Optional[str]
-        load=None,  # type: Optional[str]
-        transform=None,  # type: Optional[str]
-        **kwargs  # type: Any
-    ):
-        # type: (...) -> Any
+        value: Any,
+        get: Optional[str] = None,
+        load: Optional[str] = None,
+        transform: Optional[str] = None,
+        **kwargs: Any,
+    ) -> Any:
         """Format results to be returned by a lookup.
 
         Args:
-            value (Any): Data collected by the Lookup.
-            get (Optional[str]): Nested value to get from a dictionary like
-                object.
-            load (Optional[str]): Parser to use to parse a formatted string
-                before the ``get`` and ``transform`` method.
-            transform (Optional[str]): Convert the final value to a different
-                data type before returning it.
+            value: Data collected by the Lookup.
+            get: Nested value to get from a dictionary like object.
+            load: Parser to use to parse a formatted string before the ``get``
+                and ``transform`` method.
+            transform: Convert the final value to a different data type before
+                returning it.
 
         Raises:
             TypeError: If ``get`` is provided but the value value is not a
@@ -158,10 +57,10 @@ class LookupHandler(object):
 
         Runs the following actions in order:
 
-        1. :meth:`~LookupHandler.load` if ``load`` is provided.
+        1. :meth:`load` if ``load`` is provided.
         2. :meth:`runway.util.MutableMap.find` or :meth:`dict.get` depending
            on the data type if ``get`` is provided.
-        3. :meth:`~LookupHandler.transform` if ``transform`` is provided.
+        3. :meth:`transform` if ``transform`` is provided.
 
         """
         if load:
@@ -185,24 +84,26 @@ class LookupHandler(object):
         return value
 
     @classmethod
-    def handle(cls, value, context, **kwargs):
-        # type: (str, 'Context', Any) -> Any
+    def handle(
+        cls,
+        __value: str,
+        context: Union[CfnginContext, RunwayContext],
+        *__args: Any,
+        provider: Optional[Provider] = None,
+        **__kwargs: Any,
+    ) -> Any:
         """Perform the lookup.
 
         Args:
-            value: Parameter(s) given to the lookup.
+            __value: Parameter(s) given to the lookup.
             context: The current context object.
-            provider: Optional provider to use when handling the lookup.
-
-        Returns:
-            (Any) Looked-up value.
+            provider: CFNgin AWS provider.
 
         """
         raise NotImplementedError
 
     @classmethod
-    def parse(cls, value):
-        # type: (str) -> Tuple[str, Dict[str, str]]
+    def parse(cls, value: str) -> Tuple[str, Dict[str, str]]:
         """Parse the value passed to a lookup in a standardized way.
 
         Args:
@@ -217,13 +118,12 @@ class LookupHandler(object):
         colon_split = raw_value.split("::", 1)
 
         query = colon_split.pop(0)
-        args = cls._parse_args(colon_split[0]) if colon_split else {}
+        args: Dict[str, str] = cls._parse_args(colon_split[0]) if colon_split else {}
 
         return query, args
 
     @classmethod
-    def _parse_args(cls, args):
-        # type: (str) -> Dict[str, str]
+    def _parse_args(cls, args: str) -> Dict[str, str]:
         """Convert a string into an args dict.
 
         Each arg should be seporated by  ``,``. The key and value should
@@ -244,13 +144,12 @@ class LookupHandler(object):
         }
 
     @classmethod
-    def load(cls, value, parser=None, **kwargs):
-        # type: (str, str, Any) -> Any
+    def load(cls, value: Any, parser: Optional[str] = None, **kwargs: Any) -> Any:
         """Load a formatted string or object into a python data type.
 
-        First action taken in :meth:`~LookupHandler.format_results`.
+        First action taken in :meth:`format_results`.
         If a lookup needs to handling loading data to process it before it
-        enters :meth:`~LookupHandler.format_results`, is should use
+        enters :meth:`format_results`, is should use
         ``args.pop('load')`` to prevent the data from being loaded twice.
 
         Args:
@@ -273,16 +172,12 @@ class LookupHandler(object):
         return mapping[parser](value, **kwargs)
 
     @classmethod
-    def _load_json(cls, value, **_):
-        # type: (str, Any) -> MutableMap
+    def _load_json(cls, value: Any, **_: Any) -> MutableMap:
         """Load a JSON string into a MutableMap.
 
         Args:
             value: JSON formatted string.
 
-        Returns:
-            MutableMap
-
         """
         if not isinstance(value, str):
             raise TypeError(
@@ -294,16 +189,11 @@ class LookupHandler(object):
         return result
 
     @classmethod
-    def _load_troposphere(cls, value, **_):
-        # type: (BaseAWSObject, Any) -> MutableMap
+    def _load_troposphere(cls, value: Any, **_: Any) -> MutableMap:
         """Load a Troposphere resource into a MutableMap.
 
         Args:
-            Value (troposphere.BaseAWSObject): Troposphere resource to
-                contvert to a MutableMap for parsing.
-
-        Returns:
-            MutableMap
+            value: Troposphere resource to contvert to a MutableMap for parsing.
 
         """
         if not isinstance(value, BaseAWSObject):
@@ -318,16 +208,12 @@ class LookupHandler(object):
         )
 
     @classmethod
-    def _load_yaml(cls, value, **_):
-        # type: (str, Any) -> MutableMap
+    def _load_yaml(cls, value: Any, **_: Any) -> MutableMap:
         """Load a YAML string into a MutableMap.
 
         Args:
             value: YAML formatted string.
 
-        Returns:
-            MutableMap
-
         """
         if not isinstance(value, str):
             raise TypeError(
@@ -339,11 +225,12 @@ class LookupHandler(object):
         return result
 
     @classmethod
-    def transform(cls, value, to_type="str", **kwargs):
-        # type: (str, str, Any) -> Any
+    def transform(
+        cls, value: Any, *, to_type: Optional[str] = "str", **kwargs: Any
+    ) -> Any:
         """Transform the result of a lookup into another datatype.
 
-        Last action taken in :meth:`~LookupHandler.format_results`.
+        Last action taken in :meth:`format_results`.
         If a lookup needs to handling transforming the data in a way that
         the base class can't support it should overwrite this method of the
         base class to register different transform methods.
@@ -364,8 +251,7 @@ class LookupHandler(object):
         return mapping[to_type](value, **kwargs)  # type: ignore
 
     @classmethod
-    def _transform_to_bool(cls, value, **_):
-        # type: (Union[bool, str], Any) -> bool
+    def _transform_to_bool(cls, value: Any, **_: Any) -> bool:
         """Transform a string into a bool.
 
         Args:
@@ -378,7 +264,7 @@ class LookupHandler(object):
         """
         if isinstance(value, bool):
             return value
-        if isinstance(value, string_types):
+        if isinstance(value, str):
             return bool(strtobool(value))
         raise TypeError(
             "Value must be a string or bool to use transform=bool. Got type {}.".format(
@@ -387,8 +273,9 @@ class LookupHandler(object):
         )
 
     @classmethod
-    def _transform_to_string(cls, value, delimiter=None, **kwargs):
-        # type: (Any, str, Any) -> str
+    def _transform_to_string(
+        cls, value: Any, *, delimiter: str = ",", indent: int = 0, **_: Any
+    ) -> str:
         """Transform anything into a string.
 
         If the datatype of ``value`` is a list or similar to a list, ``join()``
@@ -398,16 +285,19 @@ class LookupHandler(object):
             value: The value to be transformed into a string.
             delimiter: Used when transforming a list like object into a string
                 to join each element together.
+            indent: Number of spaces to use when indenting JSON output.
 
         """
         if isinstance(value, (list, set, tuple)):
-            return "{}".format(delimiter or ",").join(value)
+            return "{}".format(delimiter).join(cast(Sequence[str], value))
         if isinstance(value, MutableMap):
             # convert into a dict with protected attrs removed
             value = value.data
         if isinstance(value, dict):
             # dumped twice for an escaped json dict
-            return json.dumps(json.dumps(value, indent=int(kwargs.get("indent", 0))))
+            return json.dumps(
+                json.dumps(cast(Dict[str, Any], value), indent=int(indent))
+            )
         if isinstance(value, bool):
             return json.dumps(str(value))
         return str(value)
